@@ -46,6 +46,7 @@ $conf = Config::Objective->new('test.conf',
 	{
 		'string'	=> Config::Objective::String->new(),
 		'quoted_string'	=> Config::Objective::String->new(),
+		'special_str'	=> Config::Objective::String->new(),
 		'empty_string'	=> Config::Objective::String->new(),
 		'no_value'	=> Config::Objective::String->new(
 						'value_optional' => 1
@@ -84,6 +85,7 @@ ok (defined($conf));
 
 ok ($conf->string eq '3value'
     && $conf->quoted_string eq "quoted\n\tstring\non\n\t\tmultiple\n\tlines\n\n"
+    && $conf->special_str eq 'quoted with "special" characters'
     && $conf->empty_string eq ''
     && $conf->no_value eq ''
     && $conf->path eq '/usr/local/bin');
